Index: /CKEditor/trunk/_source/core/dom/element.js
===================================================================
--- /CKEditor/trunk/_source/core/dom/element.js	(revision 6444)
+++ /CKEditor/trunk/_source/core/dom/element.js	(revision 6445)
@@ -308,4 +308,5 @@
 		/**
 		 * Moves the selection focus to this element.
+		 * @function
 		 * @param  {Boolean} defer Whether to asynchronously defer the
 		 * 		execution by 100 ms.
@@ -817,12 +818,13 @@
 
 		/**
-		 * Indicates that the element has defined attributes.
+		 * Checks if the element has any defined attributes.
+		 * @function
 		 * @returns {Boolean} True if the element has attributes.
 		 * @example
-		 * var element = CKEDITOR.dom.element.createFromHtml( '<div title="Test">Example</div>' );
-		 * alert( <b>element.hasAttributes()</b> );  "true"
-		 * @example
-		 * var element = CKEDITOR.dom.element.createFromHtml( '<div>Example</div>' );
-		 * alert( <b>element.hasAttributes()</b> );  "false"
+		 * var element = CKEDITOR.dom.element.createFromHtml( '&lt;div title="Test"&gt;Example&lt;/div&gt;' );
+		 * alert( <b>element.hasAttributes()</b> );  // "true"
+		 * @example
+		 * var element = CKEDITOR.dom.element.createFromHtml( '&lt;div&gt;Example&lt;/div&gt;' );
+		 * alert( <b>element.hasAttributes()</b> );  // "false"
 		 */
 		hasAttributes :
@@ -878,7 +880,7 @@
 
 		/**
-		 * Indicates whether a specified attribute is defined for this element.
+		 * Checks if the specified attribute is defined for this element.
 		 * @returns {Boolean} True if the specified attribute is defined.
-		 * @param (String) name The attribute name.
+		 * @param {String} name The attribute name.
 		 * @example
 		 */
@@ -1592,9 +1594,10 @@
 
 	/**
-	 * Update the element's size with box model awareness.
-	 * @name CKEDITOR.dom.element.setSize
-	 * @param {String} type [width|height]
+	 * Sets the element size considering the box model.
+	 * @name CKEDITOR.dom.element.prototype.setSize
+	 * @function
+	 * @param {String} type The dimension to set. It accepts "width" and "height".
 	 * @param {Number} size The length unit in px.
-	 * @param isBorderBox Apply the {@param width} and {@param height} based on border box model.
+	 * @param {Boolean} isBorderBox Apply the size based on the border box model.
 	 */
 	CKEDITOR.dom.element.prototype.setSize = function( type, size, isBorderBox )
@@ -1610,15 +1613,16 @@
 
 	/**
 	 * Get the element's size, possibly with box model awareness.
 	 * @name CKEDITOR.dom.element.getSize
 	 * @param {String} type [width|height]
 	 * @param {Boolean} contentSize Get the {@param width} or {@param height} based on border box model.
 	 */
-	CKEDITOR.dom.element.prototype.getSize = function( type, contentSize )
+	CKEDITOR.dom.element.prototype.getSize = function( type, isBorderBox )
 		{
 			var size = Math.max( this.$[ 'offset' + CKEDITOR.tools.capitalize( type )  ],
 				this.$[ 'client' + CKEDITOR.tools.capitalize( type )  ] ) || 0;
 
-			if ( contentSize )
+			if ( isBorderBox )
 				size -= marginAndPaddingSize.call( this, type );
 
@@ -1610,15 +1613,16 @@
 
 	/**
-	 * Get the element's size, possibly with box model awareness.
-	 * @name CKEDITOR.dom.element.getSize
-	 * @param {String} type [width|height]
-	 * @param {Boolean} contentSize Get the {@param width} or {@param height} based on border box model.
+	 * Gets the element size, possibly considering the box model.
+	 * @name CKEDITOR.dom.element.prototype.getSize
+	 * @function
+	 * @param {String} type The dimension to get. It accepts "width" and "height".
+	 * @param {Boolean} isBorderBox Get the size based on the border box model.
 	 */
